@@ -1,31 +1,29 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "checkedcollectionwidget.h"
-#include <CollectionFilterProxyModel>
+#include <Akonadi/CollectionFilterProxyModel>
 
-#include <Monitor>
-#include <EntityTreeModel>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Monitor>
 #include <QSortFilterProxyModel>
 
 #include <KCheckableProxyModel>
-#include <QLineEdit>
 #include <KLocalizedString>
+#include <QLineEdit>
 
-#include <QVBoxLayout>
 #include <QTreeView>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 
 class PimCommon::CheckedCollectionWidgetPrivate
 {
 public:
-    CheckedCollectionWidgetPrivate()
-    {
-    }
+    CheckedCollectionWidgetPrivate() = default;
 
     QTreeView *mFolderView = nullptr;
     QItemSelectionModel *mSelectionModel = nullptr;
@@ -39,11 +37,11 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     : QWidget(parent)
     , d(new PimCommon::CheckedCollectionWidgetPrivate)
 {
-    auto *vbox = new QVBoxLayout(this);
-    vbox->setContentsMargins(0, 0, 0, 0);
+    auto vbox = new QVBoxLayout(this);
+    vbox->setContentsMargins({});
 
     // Create a new change recorder.
-    auto *monitor = new Akonadi::Monitor(this);
+    auto monitor = new Akonadi::Monitor(this);
     monitor->setObjectName(QStringLiteral("CheckedCollectionWidgetMonitor"));
     monitor->fetchCollection(true);
     monitor->setAllMonitored(true);
@@ -55,7 +53,7 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     // Set the model to show only collections, not items.
     d->mEntityTreeModel->setItemPopulationStrategy(Akonadi::EntityTreeModel::NoItemPopulation);
 
-    auto *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
+    auto mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
     mimeTypeProxy->setExcludeVirtualCollections(true);
     mimeTypeProxy->addMimeTypeFilters({mimetype});
     mimeTypeProxy->setSourceModel(d->mEntityTreeModel);
@@ -70,7 +68,7 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     d->mCollectionFilter->setSourceModel(d->mCheckProxy);
     d->mCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
-    auto *searchLine = new QLineEdit(this);
+    auto searchLine = new QLineEdit(this);
     searchLine->setPlaceholderText(i18n("Search..."));
     searchLine->setClearButtonEnabled(true);
     connect(searchLine, &QLineEdit::textChanged, this, &CheckedCollectionWidget::slotSetCollectionFilter);
@@ -85,10 +83,7 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     vbox->addWidget(d->mFolderView);
 }
 
-CheckedCollectionWidget::~CheckedCollectionWidget()
-{
-    delete d;
-}
+CheckedCollectionWidget::~CheckedCollectionWidget() = default;
 
 Akonadi::EntityTreeModel *CheckedCollectionWidget::entityTreeModel() const
 {
